@@ -1,5 +1,20 @@
+from typing import NamedTuple, Union
+
 from jax import numpy as jnp
 
+
+class RollPitchYaw(NamedTuple):
+    """Tuple containing roll, pitch, and yaw Euler angles."""
+
+    roll: jnp.ndarray
+    pitch: jnp.ndarray
+    yaw: jnp.ndarray
+
+
+Scalar = Union[float, jnp.ndarray]
+"""Type alias for `Union[float, jnp.ndarray]`.
+"""
+
 Matrix = jnp.ndarray
 """Type alias for `jnp.ndarray`. Should not be instantiated.
 
@@ -23,6 +38,8 @@ Refers to a 1D array with shape `(Group.tangent_dim,)`.
 
 
 __all__ = [
+    "RollPitchYaw",
+    "Scalar",
     "Matrix",
     "Vector",
     "TangentVector",
